"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
var tslib_1 = require("tslib");
var Configuration_1 = tslib_1.__importDefault(require("./Configuration"));
var FileUtils_1 = tslib_1.__importDefault(require("./FileUtils"));
var moment_1 = tslib_1.__importDefault(require("moment"));
var utils_1 = require("./utils");
var formatFileName = function (fileName) { return fileName.replace(' ', '-'); };
var Logger = /** @class */ (function () {
    function Logger(jobInfo, loggerConfig) {
        var _this = this;
        this.logs = {
            info: [],
            warnings: [],
            errors: [],
        };
        this.loggerConfig = {
            debugLevel: 3,
            removeLocalLogFileOnSave: false,
        };
        this.useAdapter = function (adapter) {
            _this.adapter = adapter;
        };
        // Use these methods to log the execution time of the task
        this.startLogTime = function () {
            _this.startTime = moment_1.default(new Date());
        };
        this.endLogTime = function () {
            _this.endTime = moment_1.default(new Date());
        };
        // Utility methods to log messages or errors at different levels
        this.info = function (message) {
            if (_this.loggerConfig.debugLevel < 3) {
                return console.log('Debug level is less than 3, [INFO] messaged will not be logged');
            }
            var formattedMessage = _this.formatMessageByTag(message, '[INFO]');
            _this.logs.info.push(formattedMessage);
        };
        this.warn = function (message) {
            if (_this.loggerConfig.debugLevel < 3) {
                return console.log('Debug level is less than 2, [WARNING] messaged will not be logged');
            }
            var formattedMessage = _this.formatMessageByTag(message, '[WARNING]');
            _this.logs.warnings.push(formattedMessage);
        };
        this.error = function (message) {
            if (_this.loggerConfig.debugLevel < 1) {
                return console.log('Debug level is less than 1, No messages will be logged');
            }
            var formattedMessage = _this.formatMessageByTag(message, '[ERROR]');
            _this.logs.errors.push(formattedMessage);
        };
        this.setJobStatus = function (statusCode) {
            _this.jobInfo.set('STATUS_CODE', statusCode);
        };
        this.getTaskDuration = function () { return moment_1.default.duration(_this.endTime.diff(_this.startTime)); };
        this.save = function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.writeLogs();
                        if (!this.adapter) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.writeToAdapter()];
                    case 1:
                        _a.sent();
                        _a.label = 2;
                    case 2:
                        if (this.loggerConfig.removeLocalLogFileOnSave)
                            Object.values(this.logFiles).forEach(function (logFile) {
                                return logFile.removeLocalLogFile();
                            });
                        return [2 /*return*/];
                }
            });
        }); };
        this.saveNew = function () {
            _this.setUpNewLogFileHandlers();
            _this.save();
        };
        this.writeToAdapter = function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var jobTag;
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        jobTag = this.jobInfo.get('name') + "-" + this.startTime.format('DD-MM-YYYY | hh:mm:ss');
                        return [4 /*yield*/, Promise.all(Object.entries(this.logFiles).map(function (_a) {
                                var logType = _a[0], logFile = _a[1];
                                if (logFile.isAvailableOnDisk)
                                    return _this.adapter.save(logFile.filePath, logFile.filename, jobTag + "/" + logType);
                            }))];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        }); };
        this.writeLogs = function () {
            Object.entries(_this.logs).forEach(function (_a) {
                var logType = _a[0], logs = _a[1];
                if (logs.length > 0) {
                    var logFile_1 = _this.logFiles[logType];
                    _this.writeJobInfo(logFile_1);
                    logFile_1.write('\n===========================================\n');
                    logFile_1.write('LOGS\n');
                    logFile_1.write('===========================================\n');
                    logs.forEach(function (log) {
                        logFile_1.write(log);
                        logFile_1.write('\n');
                        logFile_1.write('\n');
                    });
                }
            });
        };
        this.writeJobInfo = function (logFile) {
            logFile.write('===========================================\n');
            logFile.write('JOB INFORMATION\n');
            logFile.write('===========================================\n');
            var jobConfig = _this.jobInfo.getAll();
            Object.keys(jobConfig).forEach(function (key) {
                var logMessage = utils_1.toString(jobConfig[key]);
                logFile.write(key.toUpperCase() + " : " + logMessage + "\n");
            });
            logFile.write("STARTED AT : " + _this.startTime.format('DD-MM-YYYY | hh:mm:ss') + "\n");
            logFile.write("FINISHED AT : " + _this.endTime.format('DD-MM-YYYY | hh:mm:ss') + "\n");
            var taskDuration = _this.getTaskDuration();
            logFile.write("EXECUTION TIME : " + taskDuration.hours() + " hrs " + taskDuration.minutes() + " min " + taskDuration.seconds() + " sec " + taskDuration.milliseconds() + " ms\n");
        };
        if (jobInfo) {
            this.jobInfo = new Configuration_1.default(jobInfo);
        }
        if (loggerConfig)
            this.loggerConfig = loggerConfig
                ? tslib_1.__assign(tslib_1.__assign({}, this.loggerConfig), loggerConfig) : this.loggerConfig;
        this.setUpNewLogFileHandlers();
    }
    Logger.prototype.updateConfig = function (jobInfo, loggerConfig) {
        this.jobInfo = new Configuration_1.default(jobInfo);
        this.loggerConfig = loggerConfig
            ? tslib_1.__assign(tslib_1.__assign({}, this.loggerConfig), loggerConfig) : this.loggerConfig;
    };
    Logger.prototype.setUpNewLogFileHandlers = function () {
        var jobName = formatFileName(this.jobInfo.get('name'));
        var jobDate = moment_1.default(new Date()).format('DD-MM-YYYY-hh-mm-x');
        this.logFiles = {
            info: new FileUtils_1.default(jobName + "-INFO-" + jobDate + ".log"),
            warnings: new FileUtils_1.default(jobName + "-WARNINGS-" + jobDate + ".log"),
            errors: new FileUtils_1.default(jobName + "-ERRORS-" + jobDate + ".log"),
        };
    };
    Logger.prototype.formatMessageByTag = function (message, tag) {
        var isString = typeof message === 'string';
        message = isString ? message : JSON.stringify(message, null, '\t');
        var spacer = isString ? '\t' : '\n';
        return tag + " | " + moment_1.default().format('hh:mm:ss') + " " + spacer + message;
    };
    return Logger;
}());
exports.Logger = Logger;
exports.default = Logger;
//# sourceMappingURL=Logger.js.map